descriptor

package
v0.0.0-...-c39628b Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 20, 2026 License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Overview

Package descriptor provides functionality to load and parse Protocol Buffer descriptor files.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Loader

type Loader struct {
	// contains filtered or unexported fields
}

Loader provides functionality to load field numbers from descriptor files.

func NewLoader

func NewLoader(descriptorFile string) (*Loader, error)

NewLoader creates a new descriptor loader for the given descriptor file.

func (*Loader) GetRootMessageDescriptor

func (l *Loader) GetRootMessageDescriptor(messageFullName string) (protoreflect.MessageDescriptor, error)

GetRootMessageDescriptor returns the root message descriptor for the specified messageFullName. messageFullName is required and must be a valid full name (e.g., "google.protobuf.Any").

Jump to